@@ -5,7 +5,7 @@ package OpenAPI::Modern;
 # ABSTRACT: Validate HTTP requests and responses against an OpenAPI document
 # KEYWORDS: validation evaluation JSON Schema OpenAPI Swagger HTTP request response
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -141,7 +141,7 @@ sub validate_request ($self, $request, $options) {
         $body_obj = $self->_resolve_ref($ref, $state);
       }
 
-      if ($request->content_length) {
+      if ($request->content_length // length $request->content_ref->$*) {
         ()= $self->_validate_body_content($state, $body_obj->{content}, $request);
       }
       elsif ($body_obj->{required}) {
@@ -216,7 +216,7 @@ sub validate_response ($self, $response, $options) {
 
     ()= $self->_validate_body_content({ %$state, data_path => jsonp($state->{data_path}, 'body') },
         $response_obj->{content}, $response)
-      if exists $response_obj->{content};
+      if exists $response_obj->{content} and ($response->content_length // length $response->content_ref->$*);
   }
   catch ($e) {
     if ($e->$_isa('JSON::Schema::Modern::Result')) {
@@ -501,7 +501,7 @@ OpenAPI::Modern - Validate HTTP requests and responses against an OpenAPI docume
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -703,7 +703,7 @@ C<path_template> OR C<operation_id> is required.
 
 An accessor that delegates to L<JSON::Schema::Modern::Document/canonical_uri>.
 
--head2 schema
+=head2 schema
 
 An accessor that delegates to L<JSON::Schema::Modern::Document/schema>.
 
@@ -804,8 +804,8 @@ Bugs may be submitted through L<https://github.com/karenetheridge/JSON-Schema-Mo
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org> and C<irc.libera.chat>.
 
-You can also find me on the L<JSON Schema Slack server|json-schema.slack.com> and L<OpenAPI Slack
-server|open-api.slack.com>, which are also great resources for finding help.
+You can also find me on the L<JSON Schema Slack server|https://json-schema.slack.com> and L<OpenAPI Slack
+server|https://open-api.slack.com>, which are also great resources for finding help.
 
 =head1 AUTHOR
 
